/****************************************
*  Computer Algebra System SINGULAR     *
****************************************/

// syntax table for Singular
//
// - search for an exact match of the argument types
// - otherwise search for the first possibility
//   with converted types of the arguments
// - otherwise report an error
//
// operation: ++ (identifier)  ->  nothing
// operation: -- (identifier)  ->  nothing
// operation: - (int)  ->  int
// operation: - (bigint)  ->  bigint
// operation: - (number)  ->  number
// operation: - (poly)  ->  poly
// operation: - (vector)  ->  vector
// operation: - (matrix)  ->  matrix
// operation: - (intvec)  ->  intvec
// operation: - (intmat)  ->  intmat
// operation: ( (proc)  ->  any_type
// operation: ( (string)  ->  nothing
// operation: attrib (def)  ->  nothing
// operation: bareiss (module)  ->  list
// operation: betti (list)  ->  intmat
// operation: betti (resolution)  ->  intmat
// operation: betti (ideal)  ->  intmat
// operation: betti (module)  ->  intmat
// operation: bigint (bigint)  ->  bigint
// operation: bigint (number)  ->  bigint
// operation: char (ring)  ->  int
// operation: char (qring)  ->  int
// operation: char_series (ideal)  ->  matrix
// operation: charstr (ring)  ->  string
// operation: charstr (qring)  ->  string
// operation: close (link)  ->  nothing
// operation: ncols (matrix)  ->  int
// operation: ncols (ideal)  ->  int
// operation: ncols (module)  ->  int
// operation: ncols (intmat)  ->  int
// DUMMY // operation: ncols (intvec)  ->  $INVALID$
// operation: cleardenom (poly)  ->  poly
// operation: cleardenom (vector)  ->  vector
// operation: size (number)  ->  int
// operation: size (resolution)  ->  int
// operation: size (string)  ->  int
// operation: size (poly)  ->  int
// operation: size (vector)  ->  int
// operation: size (ideal)  ->  int
// operation: size (module)  ->  int
// operation: size (matrix)  ->  int
// operation: size (intvec)  ->  int
// operation: size (intmat)  ->  int
// operation: size (list)  ->  int
// operation: size (ring)  ->  int
// operation: def (int)  ->  def
// DUMMY // operation: def (any_type)  ->  $INVALID$
// operation: deg (poly)  ->  int
// operation: deg (vector)  ->  int
// operation: deg (matrix)  ->  int
// operation: degree (ideal)  ->  nothing
// operation: degree (module)  ->  nothing
// operation: defined (def)  ->  int
// operation: det (intmat)  ->  int
// operation: det (matrix)  ->  poly
// operation: det (module)  ->  poly
// operation: dim (ideal)  ->  int
// operation: dim (module)  ->  int
// operation: dim (resolution)  ->  int
// operation: dump (link)  ->  nothing
// operation: gen (int)  ->  vector
// operation: execute (string)  ->  nothing
// operation: ERROR (string)  ->  nothing
// operation: factorize (poly)  ->  list
// operation: finduni (ideal)  ->  ideal
// operation: freemodule (int)  ->  module
// operation: facstd (ideal)  ->  list
// operation: getdump (link)  ->  nothing
// operation: highcorner (ideal)  ->  poly
// operation: highcorner (module)  ->  vector
// operation: hilb (ideal)  ->  nothing
// operation: hilb (module)  ->  nothing
// operation: hilb (intvec)  ->  intvec
// operation: homog (ideal)  ->  int
// operation: homog (module)  ->  int
// operation: ideal (vector)  ->  ideal
// operation: ideal (matrix)  ->  ideal
// operation: ideal (qring)  ->  ideal
// operation: ideal (ring)  ->  ideal
// operation: ideal (map)  ->  ideal
// operation: ideal (ideal)  ->  ideal
// operation: impart (number)  ->  number
// operation: indepSet (ideal)  ->  intvec
// operation: int (int)  ->  int
// operation: int (bigint)  ->  int
// operation: int (number)  ->  int
// operation: int (poly)  ->  int
// operation: interred (ideal)  ->  ideal
// operation: interred (module)  ->  module
// operation: intmat (intmat)  ->  intmat
// operation: intvec (intmat)  ->  intvec
// operation: intvec (intvec)  ->  intvec
// operation: rvar (poly)  ->  int
// operation: rvar (string)  ->  int
// operation: rvar (any_type)  ->  int
// operation: jacob (poly)  ->  ideal
// operation: jacob (ideal)  ->  matrix
// operation: janet (ideal)  ->  ideal
// operation: kbase (ideal)  ->  ideal
// operation: kbase (module)  ->  module
// operation: killattrib (identifier)  ->  nothing
// operation: lead (poly)  ->  poly
// operation: lead (ideal)  ->  ideal
// operation: lead (vector)  ->  vector
// operation: lead (module)  ->  module
// operation: leadcoef (poly)  ->  number
// operation: leadcoef (vector)  ->  number
// operation: leadexp (poly)  ->  intvec
// operation: leadexp (vector)  ->  intvec
// operation: leadmonom (poly)  ->  poly
// operation: leadmonom (vector)  ->  vector
// operation: LIB (string)  ->  nothing
// operation: link (link)  ->  link
// operation: list (def)  ->  list
// DUMMY // operation: map (any_type)  ->  $INVALID$
// operation: matrix (matrix)  ->  matrix
// operation: maxideal (int)  ->  ideal
// operation: memory (int)  ->  bigint
// operation: minbase (ideal)  ->  ideal
// operation: minbase (module)  ->  module
// operation: minres (list)  ->  list
// operation: minres (resolution)  ->  resolution
// operation: module (module)  ->  module
// operation: monitor (string)  ->  nothing
// operation: mult (ideal)  ->  int
// operation: mult (module)  ->  int
// operation: mstd (ideal)  ->  list
// operation: mstd (module)  ->  list
// operation: nameof (any_type)  ->  string
// operation: names (package)  ->  list
// operation: names (ring)  ->  list
// operation: names (qring)  ->  list
// operation: number (number)  ->  number
// operation: number (poly)  ->  number
// operation: number (bigint)  ->  number
// operation: npars (ring)  ->  int
// operation: npars (qring)  ->  int
// operation: nvars (ring)  ->  int
// operation: nvars (qring)  ->  int
// operation: open (link)  ->  nothing
// operation: ord (poly)  ->  int
// operation: ord (vector)  ->  int
// operation: ordstr (ring)  ->  string
// operation: ordstr (qring)  ->  string
// operation: par (int)  ->  number
// operation: pardeg (number)  ->  int
// operation: parstr (int)  ->  string
// operation: parstr (ring)  ->  string
// operation: parstr (qring)  ->  string
// operation: poly (poly)  ->  poly
// operation: poly (bigint)  ->  poly
// operation: preimage (map)  ->  ring
// operation: prime (int)  ->  int
// operation: print (list)  ->  nothing
// operation: print (def)  ->  nothing
// operation: prune (module)  ->  module
// operation: qhweight (ideal)  ->  intvec
// operation: qhweight (module)  ->  intvec
// DUMMY // operation: qring (any_type)  ->  $INVALID$
// operation: read (link)  ->  string
// operation: regularity (list)  ->  int
// operation: repart (number)  ->  number
// operation: reservedName (string)  ->  int
// operation: resolution (list)  ->  resolution
// operation: resolution (resolution)  ->  resolution
// operation: ringlist (ring)  ->  list
// operation: ringlist (qring)  ->  list
// operation: ring (ring)  ->  ring
// operation: ring (list)  ->  ring
// operation: nrows (vector)  ->  int
// operation: nrows (module)  ->  int
// operation: nrows (matrix)  ->  int
// operation: nrows (intmat)  ->  int
// operation: nrows (intvec)  ->  int
// operation: slimgb (ideal)  ->  ideal
// operation: slimgb (module)  ->  module
// operation: sortvec (ideal)  ->  intvec
// operation: sortvec (module)  ->  intvec
// operation: std (ideal)  ->  ideal
// operation: std (module)  ->  module
// operation: string (string)  ->  string
// operation: system (string)  ->  nothing
// operation: syz (ideal)  ->  module
// operation: syz (module)  ->  module
// operation: envelope (ring)  ->  ring
// operation: envelope (qring)  ->  qring
// operation: opposite (ring)  ->  ring
// operation: opposite (qring)  ->  qring
// operation: twostd (ideal)  ->  ideal
// DUMMY // operation: trace (intvec)  ->  $INVALID$
// DUMMY // operation: trace (ideal)  ->  $INVALID$
// operation: trace (intmat)  ->  int
// operation: trace (matrix)  ->  poly
// operation: transpose (intvec)  ->  intmat
// operation: transpose (intmat)  ->  intmat
// operation: transpose (matrix)  ->  matrix
// operation: transpose (module)  ->  module
// operation: typeof (any_type)  ->  string
// operation: vector (vector)  ->  vector
// operation: vdim (ideal)  ->  int
// operation: vdim (module)  ->  int
// operation: var (int)  ->  poly
// operation: varstr (int)  ->  string
// operation: varstr (ring)  ->  string
// operation: varstr (qring)  ->  string
// operation: weight (ideal)  ->  intvec
// operation: weight (module)  ->  intvec
// operation: load (string)  ->  nothing
// operation: convhull (ideal)  ->  ideal
/*---------------------------------------------*/
// operation: :: (def, def)  ->  any_type
// operation: + (int, int)  ->  int
// operation: + (bigint, bigint)  ->  bigint
// operation: + (number, number)  ->  number
// operation: + (poly, poly)  ->  poly
// operation: + (vector, vector)  ->  vector
// operation: + (ideal, ideal)  ->  ideal
// operation: + (module, module)  ->  module
// operation: + (poly, matrix)  ->  matrix
// operation: + (matrix, poly)  ->  matrix
// operation: + (matrix, matrix)  ->  matrix
// operation: + (string, string)  ->  string
// operation: + (intvec, int)  ->  intvec
// operation: + (int, intvec)  ->  intvec
// operation: + (intmat, int)  ->  intmat
// operation: + (int, intmat)  ->  intmat
// operation: + (intvec, intvec)  ->  intvec
// operation: + (intmat, intmat)  ->  intmat
// operation: + (list, list)  ->  list
// operation: + (ring, ring)  ->  ring
// operation: + (qring, ring)  ->  qring
// operation: + (ring, qring)  ->  qring
// operation: + (qring, qring)  ->  qring
// operation: - (int, int)  ->  int
// operation: - (bigint, bigint)  ->  bigint
// operation: - (number, number)  ->  number
// operation: - (poly, poly)  ->  poly
// operation: - (vector, vector)  ->  vector
// operation: - (matrix, poly)  ->  matrix
// operation: - (matrix, matrix)  ->  matrix
// operation: - (intvec, int)  ->  intvec
// operation: - (intmat, int)  ->  intmat
// operation: - (intvec, intvec)  ->  intvec
// operation: - (intmat, intmat)  ->  intmat
// operation: * (int, int)  ->  int
// operation: * (bigint, bigint)  ->  bigint
// operation: * (number, number)  ->  number
// operation: * (poly, poly)  ->  poly
// operation: * (poly, vector)  ->  vector
// operation: * (vector, poly)  ->  vector
// operation: * (ideal, poly)  ->  ideal
// operation: * (poly, ideal)  ->  ideal
// operation: * (ideal, ideal)  ->  ideal
// operation: * (ideal, vector)  ->  module
// operation: * (vector, ideal)  ->  module
// operation: * (ideal, module)  ->  module
// operation: * (module, ideal)  ->  module
// operation: * (matrix, poly)  ->  matrix
// operation: * (poly, matrix)  ->  matrix
// operation: * (matrix, number)  ->  matrix
// operation: * (number, matrix)  ->  matrix
// operation: * (matrix, int)  ->  matrix
// operation: * (int, matrix)  ->  matrix
// operation: * (matrix, matrix)  ->  matrix
// operation: * (intvec, int)  ->  intvec
// operation: * (int, intvec)  ->  intvec
// operation: * (intmat, int)  ->  intmat
// operation: * (int, intmat)  ->  intmat
// operation: * (intmat, intvec)  ->  intvec
// operation: * (intmat, intmat)  ->  intmat
// operation: * (intvec, intmat)  ->  intmat
// operation: / (number, number)  ->  number
// operation: / (poly, poly)  ->  poly
// operation: / (vector, poly)  ->  vector
// operation: / (matrix, poly)  ->  matrix
// operation: / (int, int)  ->  int
// operation: / (bigint, bigint)  ->  bigint
// operation: / (intvec, int)  ->  intvec
// operation: / (intmat, int)  ->  intmat
// operation: div (int, int)  ->  int
// operation: div (bigint, bigint)  ->  bigint
// operation: div (intvec, int)  ->  intvec
// operation: div (intmat, int)  ->  intmat
// operation: % (int, int)  ->  int
// operation: % (bigint, bigint)  ->  bigint
// operation: % (intvec, int)  ->  intvec
// operation: % (intmat, int)  ->  intmat
// operation: % (number, number)  ->  number
// operation: mod (int, int)  ->  int
// operation: mod (bigint, bigint)  ->  bigint
// operation: mod (intvec, int)  ->  intvec
// operation: mod (intmat, int)  ->  intmat
// operation: mod (number, number)  ->  number
// operation: ^ (int, int)  ->  int
// operation: ^ (bigint, int)  ->  bigint
// operation: ^ (number, int)  ->  number
// operation: ^ (poly, int)  ->  poly
// operation: ^ (ideal, int)  ->  ideal
// operation: <= (int, int)  ->  int
// operation: <= (number, number)  ->  int
// operation: <= (string, string)  ->  int
// operation: <= (intvec, int)  ->  int
// operation: <= (intvec, intvec)  ->  int
// operation: <= (poly, poly)  ->  int
// operation: <= (vector, vector)  ->  int
// operation: <= (bigint, bigint)  ->  int
// operation: < (int, int)  ->  int
// operation: < (number, number)  ->  int
// operation: < (intvec, int)  ->  int
// operation: < (intvec, intvec)  ->  int
// operation: < (string, string)  ->  int
// operation: < (poly, poly)  ->  int
// operation: < (vector, vector)  ->  int
// operation: < (bigint, bigint)  ->  int
// operation: >= (int, int)  ->  int
// operation: >= (number, number)  ->  int
// operation: >= (string, string)  ->  int
// operation: >= (intvec, int)  ->  int
// operation: >= (intvec, intvec)  ->  int
// operation: >= (poly, poly)  ->  int
// operation: >= (vector, vector)  ->  int
// operation: >= (bigint, bigint)  ->  int
// operation: > (int, int)  ->  int
// operation: > (number, number)  ->  int
// operation: > (string, string)  ->  int
// operation: > (intvec, int)  ->  int
// operation: > (intvec, intvec)  ->  int
// operation: > (poly, poly)  ->  int
// operation: > (vector, vector)  ->  int
// operation: > (bigint, bigint)  ->  int
// operation: and (int, int)  ->  int
// operation: or (int, int)  ->  int
// operation: == (int, int)  ->  int
// operation: == (number, number)  ->  int
// operation: == (string, string)  ->  int
// operation: == (poly, poly)  ->  int
// operation: == (vector, vector)  ->  int
// operation: == (intvec, int)  ->  int
// operation: == (intvec, intvec)  ->  int
// operation: == (intmat, intmat)  ->  int
// operation: == (bigint, bigint)  ->  int
// operation: == (matrix, matrix)  ->  int
// DUMMY // operation: == (ideal, ideal)  ->  $INVALID$
// DUMMY // operation: == (module, module)  ->  $INVALID$
// DUMMY // operation: == (ideal, module)  ->  $INVALID$
// DUMMY // operation: == (module, ideal)  ->  $INVALID$
// operation: <> (int, int)  ->  int
// operation: <> (number, number)  ->  int
// operation: <> (string, string)  ->  int
// operation: <> (poly, poly)  ->  int
// operation: <> (vector, vector)  ->  int
// operation: <> (intvec, intvec)  ->  int
// operation: <> (intmat, intmat)  ->  int
// operation: <> (matrix, matrix)  ->  int
// DUMMY // operation: <> (ideal, ideal)  ->  $INVALID$
// DUMMY // operation: <> (module, module)  ->  $INVALID$
// DUMMY // operation: <> (ideal, module)  ->  $INVALID$
// DUMMY // operation: <> (module, ideal)  ->  $INVALID$
// operation: .. (int, int)  ->  intvec
// operation: [ (intvec, int)  ->  int
// operation: [ (intvec, intvec)  ->  int
// operation: [ (ideal, int)  ->  poly
// operation: [ (map, int)  ->  poly
// operation: [ (ideal, intvec)  ->  poly
// operation: [ (module, int)  ->  vector
// operation: [ (module, intvec)  ->  vector
// operation: [ (string, int)  ->  string
// operation: [ (string, intvec)  ->  string
// operation: [ (list, int)  ->  any_type
// operation: [ (list, intvec)  ->  any_type
// operation: [ (poly, int)  ->  poly
// operation: [ (poly, intvec)  ->  poly
// operation: [ (vector, int)  ->  poly
// operation: [ (vector, intvec)  ->  vector
// operation: ( (proc, def)  ->  any_type
// operation: ( (map, def)  ->  any_type
// operation: ( (any_type, int)  ->  any_type
// operation: ( (any_type, intvec)  ->  any_type
// operation: : (int, int)  ->  intvec
// operation: attrib (def, string)  ->  nothing
// DUMMY // operation: bareiss (def, def)  ->  $INVALID$
// operation: betti (list, int)  ->  intmat
// operation: betti (resolution, int)  ->  intmat
// operation: betti (ideal, int)  ->  intmat
// operation: betti (module, int)  ->  intmat
// operation: bracket (poly, poly)  ->  poly
// operation: chinrem (intvec, intvec)  ->  bigint
// operation: chinrem (list, intvec)  ->  ideal
// operation: coef (poly, poly)  ->  matrix
// operation: coeffs (ideal, poly)  ->  matrix
// operation: coeffs (module, poly)  ->  matrix
// operation: coeffs (ideal, ideal)  ->  matrix
// operation: coeffs (module, module)  ->  matrix
// operation: contract (ideal, ideal)  ->  matrix
// operation: deg (poly, intvec)  ->  int
// operation: deg (vector, intvec)  ->  int
// operation: deg (matrix, intvec)  ->  int
// operation: delete (list, int)  ->  list
// operation: diff (poly, poly)  ->  poly
// operation: diff (vector, poly)  ->  vector
// operation: diff (ideal, poly)  ->  ideal
// operation: diff (ideal, ideal)  ->  matrix
// operation: diff (module, poly)  ->  module
// operation: diff (matrix, poly)  ->  matrix
// operation: dim (ideal, ideal)  ->  int
// operation: dim (module, ideal)  ->  int
// operation: division (ideal, ideal)  ->  list
// operation: division (module, module)  ->  list
// operation: eliminate (ideal, poly)  ->  ideal
// operation: eliminate (module, poly)  ->  module
// operation: exportto (package, identifier)  ->  nothing
// operation: extgcd (int, int)  ->  list
// operation: extgcd (poly, poly)  ->  list
// operation: factorize (poly, int)  ->  ideal
// operation: facstd (ideal, ideal)  ->  list
// operation: fetch (ring, any_type)  ->  any_type
// operation: fetch (qring, any_type)  ->  any_type
// operation: fglm (ring, def)  ->  ideal
// operation: fglm (qring, def)  ->  ideal
// operation: fglmquot (ideal, poly)  ->  ideal
// operation: find (string, string)  ->  int
// operation: frwalk (ring, def)  ->  ideal
// operation: gcd (int, int)  ->  int
// operation: gcd (number, number)  ->  number
// operation: gcd (bigint, bigint)  ->  bigint
// operation: gcd (poly, poly)  ->  poly
// operation: hilb (ideal, int)  ->  intvec
// operation: hilb (module, int)  ->  intvec
// operation: homog (poly, poly)  ->  poly
// operation: homog (vector, poly)  ->  vector
// operation: homog (ideal, poly)  ->  ideal
// operation: homog (module, poly)  ->  module
// operation: hres (ideal, int)  ->  resolution
// operation: ideal (def, def)  ->  ideal
// operation: imap (ring, any_type)  ->  any_type
// operation: imap (qring, any_type)  ->  any_type
// operation: importfrom (package, any_type)  ->  nothing
// operation: indepSet (ideal, int)  ->  list
// operation: insert (list, def)  ->  list
// operation: interpolation (list, intvec)  ->  ideal
// operation: intersect (ideal, ideal)  ->  ideal
// operation: intersect (module, module)  ->  module
// operation: janet (ideal, int)  ->  ideal
// operation: jet (poly, int)  ->  poly
// operation: jet (ideal, int)  ->  ideal
// operation: jet (vector, int)  ->  vector
// operation: jet (module, int)  ->  module
// operation: jet (matrix, int)  ->  matrix
// operation: kbase (ideal, int)  ->  ideal
// operation: kbase (module, int)  ->  module
// operation: killattrib (identifier, string)  ->  nothing
// operation: koszul (int, int)  ->  matrix
// operation: koszul (int, ideal)  ->  matrix
// operation: kres (ideal, int)  ->  resolution
// operation: lift (ideal, ideal)  ->  matrix
// operation: lift (module, module)  ->  matrix
// operation: liftstd (ideal, matrix)  ->  ideal
// operation: liftstd (module, matrix)  ->  module
// operation: list (def, def)  ->  list
// operation: load (string, string)  ->  nothing
// operation: lres (ideal, int)  ->  resolution
// operation: minor (matrix, int)  ->  ideal
// operation: module (def, def)  ->  module
// operation: modulo (ideal, ideal)  ->  module
// operation: modulo (module, module)  ->  module
// operation: monitor (string, string)  ->  nothing
// operation: mpresmat (ideal, int)  ->  module
// operation: mres (ideal, int)  ->  resolution
// operation: mres (module, int)  ->  resolution
// operation: ncalgebra (poly, poly)  ->  nothing
// operation: ncalgebra (poly, matrix)  ->  nothing
// operation: ncalgebra (matrix, poly)  ->  nothing
// operation: ncalgebra (matrix, matrix)  ->  nothing
// operation: oppose (ring, def)  ->  any_type
// operation: oppose (qring, def)  ->  any_type
// operation: parstr (ring, int)  ->  string
// operation: parstr (qring, int)  ->  string
// operation: print (def, string)  ->  any_type
// operation: quotient (ideal, ideal)  ->  ideal
// operation: quotient (module, ideal)  ->  module
// operation: quotient (module, module)  ->  ideal
// operation: random (int, int)  ->  int
// operation: read (link, string)  ->  string
// operation: reduce (poly, ideal)  ->  poly
// operation: reduce (vector, ideal)  ->  vector
// operation: reduce (vector, module)  ->  vector
// operation: reduce (ideal, ideal)  ->  ideal
// operation: reduce (module, module)  ->  module
// operation: reduce (module, ideal)  ->  module
// operation: nres (ideal, int)  ->  resolution
// operation: nres (module, int)  ->  resolution
// operation: status (link, string)  ->  string
// operation: simplify (poly, int)  ->  poly
// operation: simplify (vector, int)  ->  vector
// operation: simplify (ideal, int)  ->  ideal
// operation: simplify (module, int)  ->  module
// operation: sres (ideal, int)  ->  resolution
// operation: sres (module, int)  ->  resolution
// operation: system (string, def)  ->  any_type
// operation: std (ideal, poly)  ->  ideal
// operation: std (module, vector)  ->  module
// operation: std (ideal, ideal)  ->  ideal
// operation: std (module, module)  ->  module
// operation: std (ideal, intvec)  ->  ideal
// operation: std (module, intvec)  ->  module
// operation: varstr (ring, int)  ->  string
// operation: varstr (qring, int)  ->  string
// operation: wedge (matrix, int)  ->  matrix
/*---------------------------------------------*/
// operation: [ (string, int, int)  ->  string
// operation: [ (intmat, int, int)  ->  int
// operation: [ (intmat, int, intvec)  ->  int
// operation: [ (intmat, intvec, int)  ->  int
// operation: [ (intmat, intvec, intvec)  ->  int
// operation: [ (matrix, int, int)  ->  poly
// operation: [ (matrix, int, intvec)  ->  poly
// operation: [ (matrix, intvec, int)  ->  poly
// operation: [ (matrix, intvec, intvec)  ->  poly
// operation: ( (proc, def, def)  ->  any_type
// operation: attrib (identifier, string, def)  ->  nothing
// operation: bareiss (module, int, int)  ->  list
// operation: coeffs (poly, poly, matrix)  ->  matrix
// operation: coeffs (vector, poly, matrix)  ->  matrix
// operation: coeffs (ideal, poly, matrix)  ->  matrix
// operation: coeffs (module, poly, matrix)  ->  matrix
// operation: coeffs (ideal, ideal, poly)  ->  matrix
// operation: coeffs (module, module, poly)  ->  matrix
// operation: eliminate (ideal, poly, intvec)  ->  ideal
// operation: find (string, string, int)  ->  int
// operation: frwalk (ring, def, int)  ->  ideal
// operation: hilb (ideal, int, intvec)  ->  intvec
// operation: hilb (module, int, intvec)  ->  intvec
// operation: ideal (def, def, def)  ->  ideal
// operation: insert (list, def, int)  ->  list
// operation: intmat (intmat, int, int)  ->  intmat
// operation: intvec (def, def, def)  ->  intvec
// operation: jet (poly, int, intvec)  ->  poly
// operation: jet (ideal, int, intvec)  ->  ideal
// operation: jet (vector, int, intvec)  ->  vector
// operation: jet (module, int, intvec)  ->  module
// operation: jet (poly, poly, int)  ->  poly
// operation: jet (vector, poly, int)  ->  vector
// operation: jet (ideal, matrix, int)  ->  ideal
// operation: jet (module, matrix, int)  ->  module
// DUMMY // operation: jet (poly, int, int)  ->  poly
// operation: koszul (int, int, ideal)  ->  matrix
// operation: list (def, def, def)  ->  list
// operation: matrix (ideal, int, int)  ->  matrix
// operation: matrix (module, int, int)  ->  matrix
// operation: matrix (matrix, int, int)  ->  matrix
// operation: minor (matrix, int, ideal)  ->  ideal
// operation: module (def, def, def)  ->  module
// operation: lift (ideal, ideal, matrix)  ->  matrix
// operation: lift (module, module, matrix)  ->  matrix
// operation: preimage (ring, any_type, any_type)  ->  ideal
// operation: preimage (qring, any_type, any_type)  ->  ideal
// operation: random (int, int, int)  ->  intmat
// operation: reduce (poly, ideal, int)  ->  poly
// operation: reduce (vector, ideal, int)  ->  vector
// operation: reduce (vector, module, int)  ->  vector
// operation: reduce (ideal, ideal, int)  ->  ideal
// operation: reduce (module, module, int)  ->  module
// operation: reduce (module, ideal, int)  ->  module
// operation: reduce (poly, poly, ideal)  ->  poly
// operation: reduce (vector, poly, module)  ->  vector
// operation: reduce (ideal, ideal, matrix)  ->  ideal
// operation: reduce (module, module, matrix)  ->  module
// operation: resultant (poly, poly, poly)  ->  poly
// operation: ring (def, def, def)  ->  ring
// operation: status (link, string, string)  ->  int
// operation: std (ideal, intvec, intvec)  ->  ideal
// operation: std (module, intvec, intvec)  ->  module
// operation: subst (poly, poly, poly)  ->  poly
// operation: subst (poly, poly, poly)  ->  poly
// operation: subst (vector, poly, poly)  ->  vector
// operation: subst (ideal, poly, poly)  ->  ideal
// operation: subst (module, poly, poly)  ->  module
// operation: subst (matrix, poly, poly)  ->  matrix
// operation: subst (matrix, poly, int)  ->  matrix
// operation: subst (matrix, poly, number)  ->  matrix
// operation: system (string, def, def)  ->  nothing
// operation: laguerre (poly, int, int)  ->  list
// operation: vandermonde (ideal, ideal, int)  ->  poly
/*---------------------------------------------*/
// operation: ( (...)  ->  any_type ( number of arguments >0 )
// operation: breakpoint (...)  ->  nothing ( 0 arguments )
// operation: breakpoint (...)  ->  nothing ( number of arguments >0 )
// operation: coef (...)  ->  matrix ( 2 arguments )
// operation: coef (...)  ->  nothing ( 4 arguments )
// operation: division (...)  ->  any_type ( 2 arguments )
// operation: division (...)  ->  any_type ( 3 arguments )
// operation: division (...)  ->  any_type ( 4 arguments )
// operation: dbprint (...)  ->  nothing ( number of arguments >0 )
// operation: ideal (...)  ->  ideal ( 1 arguments )
// operation: ideal (...)  ->  ideal ( any number of arguments )
// operation: intersect (...)  ->  ideal ( 2 arguments )
// operation: intersect (...)  ->  ideal ( number of arguments >0 )
// operation: intvec (...)  ->  intvec ( 1 arguments )
// operation: intvec (...)  ->  intvec ( number of arguments >0 )
// operation: jet (...)  ->  poly ( 2 arguments )
// operation: jet (...)  ->  poly ( 3 arguments )
// operation: jet (...)  ->  poly ( 4 arguments )
// operation: list (...)  ->  list ( any number of arguments )
// operation: module (...)  ->  module ( 1 arguments )
// operation: module (...)  ->  module ( any number of arguments )
// operation: names (...)  ->  list ( 1 arguments )
// operation: names (...)  ->  list ( 0 arguments )
// operation: option (...)  ->  string ( any number of arguments )
// operation: reduce (...)  ->  ideal ( 2 arguments )
// operation: reduce (...)  ->  ideal ( 3 arguments )
// operation: reduce (...)  ->  ideal ( 4 arguments )
// operation: reduce (...)  ->  ideal ( 5 arguments )
// operation: reservedName (...)  ->  int ( 1 arguments )
// operation: reservedName (...)  ->  nothing ( 0 arguments )
// operation: string (...)  ->  string ( any number of arguments )
// operation: subst (...)  ->  nothing ( 3 arguments )
// operation: subst (...)  ->  nothing ( number of arguments >0 )
// operation: system (...)  ->  nothing ( number of arguments >0 )
// operation: test (...)  ->  nothing ( number of arguments >0 )
// operation: write (...)  ->  nothing ( number of arguments >0 )
// operation: status (...)  ->  string ( 2 arguments )
// operation: status (...)  ->  int ( 3 arguments )
// operation: status (...)  ->  int ( 4 arguments )
// operation: simplex (...)  ->  list ( 6 arguments )
// operation: uressolve (...)  ->  list ( 4 arguments )
/*---------------------------------------------*/
// assign: ideal =  ideal
// assign: ideal =  matrix
// assign: resolution =  resolution
// assign: int =  int
// assign: matrix =  matrix
// assign: map =  ideal
// assign: map =  map
// assign: module =  module
// assign: module =  poly
// assign: poly =  poly
// assign: poly =  matrix
// assign: qring =  ideal
// assign: ring =  ring
// assign: qring =  qring
// assign: string =  string
// assign: proc =  string
// assign: proc =  proc
// assign: vector =  vector
// assign: intvec =  intvec
// assign: intmat =  intmat
// assign: number =  number
// assign: bigint =  bigint
// assign: list =  resolution
// assign: list =  list
// assign: link =  string
// assign: link =  link
// assign: package =  package
/*---------------------------------------------*/
// convert intvec -> intmat
// convert poly -> ideal
// convert int -> ideal
// convert intmat -> matrix
// convert ideal -> matrix
// convert module -> matrix
// convert number -> matrix
// convert poly -> matrix
// convert vector -> matrix
// convert int -> matrix
// convert intvec -> matrix
// convert ideal -> module
// convert matrix -> module
// convert vector -> module
// convert int -> number
// convert number -> poly
// convert int -> poly
// convert list -> resolution
// convert poly -> vector
// convert int -> vector
// convert int -> bigint
// convert int -> intvec
// convert string -> link
// convert resolution -> list
/*---------------------------------------------*/
// token 61 : =
// token 62 : >
// token 60 : <
// token 43 : +
// token 42 : *
// token 47 : /
// token 91 : [
// token 46 : .
// token 94 : ^
// token 44 : ,
// token 37 : %
// token 40 : (
// token 59 : ;
// token 257 : ..
// token 258 : ==
// token 259 : >=
// token 260 : <=
// token 261 : --
// token 262 : not
// token 263 : <>
// token 264 : ++
// token 265 : ::
// token 267 : intmat
// token 268 : proc
// token 269 : ring
// token 271 : ideal
// token 272 : map
// token 273 : matrix
// token 274 : module
// token 275 : number
// token 276 : poly
// token 277 : resolution
// token 278 : vector
// token 279 : betti
// token 280 : coeffs
// token 281 : coef
// token 282 : contract
// token 283 : degree
// token 284 : deg
// token 285 : diff
// token 286 : dim
// token 287 : division
// token 288 : eliminate
// token 289 : gen
// token 290 : fetch
// token 291 : freemodule
// token 292 : keepring
// token 293 : hilb
// token 294 : homog
// token 295 : imap
// token 296 : indepSet
// token 297 : interred
// token 298 : intersect
// token 299 : jacob
// token 300 : jet
// token 301 : kbase
// token 302 : koszul
// token 303 : leadcoef
// token 304 : leadexp
// token 305 : lead
// token 306 : leadmonom
// token 307 : liftstd
// token 308 : lift
// token 309 : maxideal
// token 310 : minbase
// token 311 : minor
// token 312 : minres
// token 313 : modulo
// token 314 : mres
// token 315 : mult
// token 316 : ord
// token 317 : par
// token 318 : pardeg
// token 319 : preimage
// token 320 : quotient
// token 321 : qhweight
// token 322 : reduce
// token 323 : regularity
// token 324 : nres
// token 325 : simplify
// token 326 : sortvec
// token 327 : sres
// token 328 : std
// token 329 : subst
// token 330 : syz
// token 331 : var
// token 332 : vdim
// token 333 : wedge
// token 334 : weight
// token 336 : degBound
// token 337 : multBound
// token 338 : noether
// token 339 : minpoly
// token 340 : nothing
// token 352 : example
// token 353 : export
// token 355 : kill
// token 356 : LIB
// token 357 : listvar
// token 358 : setring
// token 359 : type
// token 366 : break
// token 367 : continue
// token 368 : else
// token 369 : eval
// token 370 : quote
// token 372 : forif
// token 375 : return
// token 376 : parameter
// token 381 : any_type
// token 382 : identifier
// token 394 : attrib
// token 395 : bareiss
// token 396 : bigint
// token 397 : bracket
// token 398 : breakpoint
// token 399 : char
// token 400 : charstr
// token 401 : char_series
// token 402 : chinrem
// token 403 : close
// token 404 : ncols
// token 405 : cleardenom
// token 406 : size
// token 407 : dbprint
// token 408 : def
// token 409 : defined
// token 410 : delete
// token 411 : det
// token 412 : dump
// token 413 : RETURN
// token 414 : envelope
// token 415 : ERROR
// token 416 : execute
// token 417 : exportto
// token 418 : extgcd
// token 419 : factorize
// token 420 : find
// token 421 : facstd
// token 422 : frwalk
// token 423 : fglm
// token 424 : fglmquot
// token 425 : finduni
// token 426 : gcd
// token 427 : getdump
// token 428 : highcorner
// token 429 : hres
// token 430 : impart
// token 431 : importfrom
// token 432 : insert
// token 433 : int
// token 434 : div
// token 435 : interpolation
// token 436 : mod
// token 437 : intvec
// token 438 : rvar
// token 439 : janet
// token 440 : killattrib
// token 441 : kres
// token 442 : laguerre
// token 443 : link
// token 444 : list
// token 445 : load
// token 446 : lres
// token 447 : memory
// token 448 : monitor
// token 449 : mpresmat
// token 450 : mstd
// token 451 : nameof
// token 452 : names
// token 453 : ncalgebra
// token 454 : convhull
// token 455 : npars
// token 456 : nvars
// token 457 : open
// token 458 : oppose
// token 459 : opposite
// token 460 : option
// token 461 : ordstr
// token 462 : package
// token 463 : parstr
// token 465 : prime
// token 466 : print
// token 467 : prune
// token 468 : qring
// token 469 : random
// token 470 : read
// token 471 : repart
// token 472 : reservedName
// token 473 : resultant
// token 474 : ringlist
// token 475 : nrows
// token 476 : simplex
// token 477 : slimgb
// token 479 : status
// token 480 : string
// token 481 : system
// token 482 : test
// token 483 : transpose
// token 484 : trace
// token 485 : twostd
// token 486 : typeof
// token 488 : uressolve
// token 489 : vandermonde
// token 490 : varstr
// token 491 : write
// token 492 : echo
// token 493 : pagelength
// token 494 : pagewidth
// token 495 : timer
// token 496 : rtimer
// token 497 : TRACE
// token 498 : voice
// token 499 : short
// token 500 : printlevel
/*--max. token: 501, gr: 378 --*/
/*---------------------------------------------*/
struct sValCmdTab dArithTab1[]=
{
 { 40,10 },
 { 45,2 },
 { 261,1 },
 { 264,0 },
 { 267,89 },
 { 269,167 },
 { 271,75 },
 { 272,114 },
 { 273,115 },
 { 274,122 },
 { 275,132 },
 { 276,149 },
 { 277,163 },
 { 278,198 },
 { 279,14 },
 { 283,50 },
 { 284,47 },
 { 286,56 },
 { 289,60 },
 { 291,65 },
 { 293,70 },
 { 294,73 },
 { 296,82 },
 { 297,87 },
 { 299,95 },
 { 301,98 },
 { 303,105 },
 { 304,107 },
 { 305,101 },
 { 306,109 },
 { 309,116 },
 { 310,118 },
 { 312,120 },
 { 315,124 },
 { 316,140 },
 { 317,144 },
 { 318,145 },
 { 319,151 },
 { 321,156 },
 { 323,160 },
 { 326,176 },
 { 328,178 },
 { 330,182 },
 { 331,201 },
 { 332,199 },
 { 334,205 },
 { 356,111 },
 { 394,12 },
 { 395,13 },
 { 396,18 },
 { 399,20 },
 { 400,23 },
 { 401,22 },
 { 403,25 },
 { 404,26 },
 { 405,31 },
 { 406,33 },
 { 408,45 },
 { 409,52 },
 { 411,53 },
 { 412,59 },
 { 414,184 },
 { 415,62 },
 { 416,61 },
 { 419,63 },
 { 421,66 },
 { 425,64 },
 { 427,67 },
 { 428,68 },
 { 430,81 },
 { 433,83 },
 { 437,90 },
 { 438,92 },
 { 439,97 },
 { 440,100 },
 { 443,112 },
 { 444,113 },
 { 445,207 },
 { 447,117 },
 { 448,123 },
 { 450,126 },
 { 451,128 },
 { 452,129 },
 { 454,208 },
 { 455,135 },
 { 456,137 },
 { 457,139 },
 { 459,186 },
 { 461,142 },
 { 463,146 },
 { 465,152 },
 { 466,153 },
 { 467,155 },
 { 468,158 },
 { 470,159 },
 { 471,161 },
 { 472,162 },
 { 474,165 },
 { 475,169 },
 { 477,174 },
 { 480,180 },
 { 481,181 },
 { 483,193 },
 { 484,189 },
 { 485,188 },
 { 486,197 },
 { 490,202 },
 { 10000,0 }
};
#define JJTAB1LEN 107
struct sValCmdTab dArithTab2[]=
{
 { 37,73 },
 { 38,120 },
 { 40,164 },
 { 42,34 },
 { 43,1 },
 { 45,23 },
 { 47,61 },
 { 58,168 },
 { 60,96 },
 { 62,112 },
 { 91,149 },
 { 94,83 },
 { 124,121 },
 { 257,148 },
 { 258,122 },
 { 259,104 },
 { 260,88 },
 { 263,136 },
 { 265,0 },
 { 271,223 },
 { 274,252 },
 { 279,171 },
 { 280,179 },
 { 281,178 },
 { 282,183 },
 { 284,184 },
 { 285,188 },
 { 286,194 },
 { 287,196 },
 { 288,198 },
 { 290,205 },
 { 293,216 },
 { 294,218 },
 { 295,224 },
 { 296,227 },
 { 298,230 },
 { 300,233 },
 { 301,238 },
 { 302,241 },
 { 307,246 },
 { 308,244 },
 { 311,251 },
 { 313,253 },
 { 314,257 },
 { 320,268 },
 { 322,273 },
 { 324,279 },
 { 325,282 },
 { 327,286 },
 { 328,289 },
 { 333,297 },
 { 394,169 },
 { 395,170 },
 { 397,175 },
 { 402,176 },
 { 410,187 },
 { 417,200 },
 { 418,201 },
 { 419,203 },
 { 420,210 },
 { 421,204 },
 { 422,211 },
 { 423,207 },
 { 424,209 },
 { 426,212 },
 { 429,222 },
 { 431,226 },
 { 432,228 },
 { 434,69 },
 { 435,229 },
 { 436,78 },
 { 439,232 },
 { 440,240 },
 { 441,243 },
 { 444,248 },
 { 445,249 },
 { 446,250 },
 { 448,255 },
 { 449,256 },
 { 453,259 },
 { 458,263 },
 { 463,265 },
 { 466,267 },
 { 469,271 },
 { 470,272 },
 { 479,281 },
 { 481,288 },
 { 490,295 },
 { 10000,0 }
};
#define JJTAB2LEN 88
/****************************************
*  Computer Algebra System SINGULAR     *
****************************************/

// identifier table for Singular
//
#ifdef MODULE_GENERATOR
#define omAlloc0(A) malloc(A)
#endif
void iiInitCmdName() {
  sArithBase.nCmdUsed      = 0;
  sArithBase.nCmdAllocated = 209;
  sArithBase.sCmds = (cmdnames*)omAlloc0(sArithBase.nCmdAllocated*sizeof(cmdnames));

  // name-string                   alias  tokval toktype index
  iiArithAddCmd("$INVALID$",           0,  -1, 0, 0);
  iiArithAddCmd("ERROR",               0, 415, CMD_1, 1);
  iiArithAddCmd("EXTGCD",              2, 418, CMD_2, 2);
  iiArithAddCmd("GCD",                 2, 426, CMD_2, 3);
  iiArithAddCmd("IN",                  1, 305, CMD_1, 4);
  iiArithAddCmd("LIB",                 0, 356, SYSVAR, 5);
  iiArithAddCmd("NF",                  1, 322, CMD_M, 6);
  iiArithAddCmd("RETURN",              0, 413, 375, 7);
  iiArithAddCmd("TRACE",               0, 497, SYSVAR, 8);
  iiArithAddCmd("and",                 0,  38, '&', 9);
  iiArithAddCmd("attrib",              0, 394, CMD_123, 10);
  iiArithAddCmd("bareiss",             0, 395, CMD_123, 11);
  iiArithAddCmd("betti",               0, 279, CMD_12, 12);
  iiArithAddCmd("bigint",              0, 396, ROOT_DECL, 13);
  iiArithAddCmd("bracket",             0, 397, CMD_2, 14);
  iiArithAddCmd("break",               0, 366, 366, 15);
  iiArithAddCmd("breakpoint",          0, 398, CMD_M, 16);
  iiArithAddCmd("char",                0, 399, CMD_1, 17);
  iiArithAddCmd("char_series",         0, 401, CMD_1, 18);
  iiArithAddCmd("charstr",             0, 400, CMD_1, 19);
  iiArithAddCmd("chinrem",             0, 402, CMD_2, 20);
  iiArithAddCmd("cleardenom",          0, 405, CMD_1, 21);
  iiArithAddCmd("close",               0, 403, CMD_1, 22);
  iiArithAddCmd("coef",                0, 281, CMD_M, 23);
  iiArithAddCmd("coeffs",              0, 280, CMD_23, 24);
  iiArithAddCmd("continue",            0, 367, 367, 25);
  iiArithAddCmd("contract",            0, 282, CMD_2, 26);
  iiArithAddCmd("convhull",            0, 454, CMD_1, 27);
  iiArithAddCmd("dbprint",             0, 407, CMD_M, 28);
  iiArithAddCmd("def",                 0, 408, ROOT_DECL, 29);
  iiArithAddCmd("defined",             0, 409, CMD_1, 30);
  iiArithAddCmd("deg",                 0, 284, CMD_12, 31);
  iiArithAddCmd("degBound",            0, 336, SYSVAR, 32);
  iiArithAddCmd("degree",              0, 283, CMD_1, 33);
  iiArithAddCmd("delete",              0, 410, CMD_2, 34);
  iiArithAddCmd("det",                 0, 411, CMD_1, 35);
  iiArithAddCmd("diff",                0, 285, CMD_2, 36);
  iiArithAddCmd("dim",                 0, 286, CMD_1, 37);
  iiArithAddCmd("div",                 0, 434, '/', 38);
  iiArithAddCmd("division",            0, 287, CMD_M, 39);
  iiArithAddCmd("dump",                0, 412, CMD_1, 40);
  iiArithAddCmd("echo",                0, 492, SYSVAR, 41);
  iiArithAddCmd("eliminate",           0, 288, CMD_23, 42);
  iiArithAddCmd("else",                0, 368, 368, 43);
  iiArithAddCmd("envelope",            0, 414, CMD_1, 44);
  iiArithAddCmd("eval",                0, 369, 369, 45);
  iiArithAddCmd("example",             0, 352, 352, 46);
  iiArithAddCmd("execute",             0, 416, CMD_1, 47);
  iiArithAddCmd("export",              0, 353, 353, 48);
  iiArithAddCmd("exportto",            0, 417, CMD_2, 49);
  iiArithAddCmd("extgcd",              0, 418, CMD_2, 50);
  iiArithAddCmd("facstd",              0, 421, CMD_12, 51);
  iiArithAddCmd("factorize",           0, 419, CMD_12, 52);
  iiArithAddCmd("fetch",               0, 290, CMD_2, 53);
  iiArithAddCmd("fglm",                0, 423, CMD_2, 54);
  iiArithAddCmd("fglmquot",            0, 424, CMD_2, 55);
  iiArithAddCmd("find",                0, 420, CMD_23, 56);
  iiArithAddCmd("finduni",             0, 425, CMD_1, 57);
  iiArithAddCmd("forif",               0, 372, 372, 58);
  iiArithAddCmd("freemodule",          0, 291, CMD_1, 59);
  iiArithAddCmd("frwalk",              0, 422, CMD_23, 60);
  iiArithAddCmd("gcd",                 0, 426, CMD_2, 61);
  iiArithAddCmd("gen",                 0, 289, CMD_1, 62);
  iiArithAddCmd("getdump",             0, 427, CMD_1, 63);
  iiArithAddCmd("highcorner",          0, 428, CMD_1, 64);
  iiArithAddCmd("hilb",                0, 293, CMD_123, 65);
  iiArithAddCmd("homog",               0, 294, CMD_12, 66);
  iiArithAddCmd("hres",                0, 429, CMD_2, 67);
  iiArithAddCmd("ideal",               0, 271, 271, 68);
  iiArithAddCmd("if",                  0, 372, 372, 69);
  iiArithAddCmd("imap",                0, 295, CMD_2, 70);
  iiArithAddCmd("impart",              0, 430, CMD_1, 71);
  iiArithAddCmd("importfrom",          0, 431, CMD_2, 72);
  iiArithAddCmd("indepSet",            0, 296, CMD_12, 73);
  iiArithAddCmd("insert",              0, 432, CMD_23, 74);
  iiArithAddCmd("int",                 0, 433, ROOT_DECL, 75);
  iiArithAddCmd("interpolation",       0, 435, CMD_2, 76);
  iiArithAddCmd("interred",            0, 297, CMD_1, 77);
  iiArithAddCmd("intersect",           0, 298, CMD_M, 78);
  iiArithAddCmd("intmat",              0, 267, 267, 79);
  iiArithAddCmd("intvec",              0, 437, ROOT_DECL_LIST, 80);
  iiArithAddCmd("jacob",               0, 299, CMD_1, 81);
  iiArithAddCmd("janet",               0, 439, CMD_12, 82);
  iiArithAddCmd("jet",                 0, 300, CMD_M, 83);
  iiArithAddCmd("kbase",               0, 301, CMD_12, 84);
  iiArithAddCmd("keepring",            0, 292, 292, 85);
  iiArithAddCmd("kill",                0, 355, 355, 86);
  iiArithAddCmd("killattrib",          0, 440, CMD_12, 87);
  iiArithAddCmd("koszul",              0, 302, CMD_23, 88);
  iiArithAddCmd("kres",                0, 441, CMD_2, 89);
  iiArithAddCmd("laguerre",            0, 442, CMD_3, 90);
  iiArithAddCmd("lead",                0, 305, CMD_1, 91);
  iiArithAddCmd("leadcoef",            0, 303, CMD_1, 92);
  iiArithAddCmd("leadexp",             0, 304, CMD_1, 93);
  iiArithAddCmd("leadmonom",           0, 306, CMD_1, 94);
  iiArithAddCmd("lift",                0, 308, CMD_23, 95);
  iiArithAddCmd("liftstd",             0, 307, CMD_2, 96);
  iiArithAddCmd("link",                0, 443, ROOT_DECL, 97);
  iiArithAddCmd("list",                0, 444, ROOT_DECL_LIST, 98);
  iiArithAddCmd("listvar",             0, 357, 357, 99);
  iiArithAddCmd("load",                0, 445, CMD_12, 100);
  iiArithAddCmd("lres",                0, 446, CMD_2, 101);
  iiArithAddCmd("map",                 0, 272, RING_DECL, 102);
  iiArithAddCmd("matrix",              0, 273, 273, 103);
  iiArithAddCmd("maxideal",            0, 309, CMD_1, 104);
  iiArithAddCmd("memory",              0, 447, CMD_1, 105);
  iiArithAddCmd("minbase",             0, 310, CMD_1, 106);
  iiArithAddCmd("minor",               0, 311, CMD_23, 107);
  iiArithAddCmd("minpoly",             0, 339, SYSVAR, 108);
  iiArithAddCmd("minres",              0, 312, CMD_1, 109);
  iiArithAddCmd("mod",                 0, 436, '/', 110);
  iiArithAddCmd("module",              0, 274, 274, 111);
  iiArithAddCmd("modulo",              0, 313, CMD_2, 112);
  iiArithAddCmd("monitor",             0, 448, CMD_12, 113);
  iiArithAddCmd("mpresmat",            0, 449, CMD_2, 114);
  iiArithAddCmd("mres",                0, 314, CMD_2, 115);
  iiArithAddCmd("mstd",                0, 450, CMD_1, 116);
  iiArithAddCmd("mult",                0, 315, CMD_1, 117);
  iiArithAddCmd("multBound",           0, 337, SYSVAR, 118);
  iiArithAddCmd("multiplicity",        1, 315, CMD_1, 119);
  iiArithAddCmd("nameof",              0, 451, CMD_1, 120);
  iiArithAddCmd("names",               0, 452, CMD_M, 121);
  iiArithAddCmd("ncalgebra",           0, 453, CMD_2, 122);
  iiArithAddCmd("ncols",               0, 404, CMD_1, 123);
  iiArithAddCmd("noether",             0, 338, SYSVAR, 124);
  iiArithAddCmd("not",                 0, 262, 262, 125);
  iiArithAddCmd("npars",               0, 455, CMD_1, 126);
  iiArithAddCmd("nres",                0, 324, CMD_2, 127);
  iiArithAddCmd("nrows",               0, 475, CMD_1, 128);
  iiArithAddCmd("number",              0, 275, RING_DECL, 129);
  iiArithAddCmd("nvars",               0, 456, CMD_1, 130);
  iiArithAddCmd("open",                0, 457, CMD_1, 131);
  iiArithAddCmd("oppose",              0, 458, CMD_2, 132);
  iiArithAddCmd("opposite",            0, 459, CMD_1, 133);
  iiArithAddCmd("option",              0, 460, CMD_M, 134);
  iiArithAddCmd("or",                  0, 124, '&', 135);
  iiArithAddCmd("ord",                 0, 316, CMD_1, 136);
  iiArithAddCmd("ordstr",              0, 461, CMD_1, 137);
  iiArithAddCmd("package",             0, 462, ROOT_DECL, 138);
  iiArithAddCmd("pagelength",          0, 493, SYSVAR, 139);
  iiArithAddCmd("pagewidth",           0, 494, SYSVAR, 140);
  iiArithAddCmd("par",                 0, 317, CMD_1, 141);
  iiArithAddCmd("parameter",           0, 376, 376, 142);
  iiArithAddCmd("pardeg",              0, 318, CMD_1, 143);
  iiArithAddCmd("parstr",              0, 463, CMD_12, 144);
  iiArithAddCmd("poly",                0, 276, RING_DECL, 145);
  iiArithAddCmd("preimage",            0, 319, 345, 146);
  iiArithAddCmd("prime",               0, 465, CMD_1, 147);
  iiArithAddCmd("print",               0, 466, CMD_12, 148);
  iiArithAddCmd("printlevel",          0, 500, SYSVAR, 149);
  iiArithAddCmd("proc",                0, 268, 268, 150);
  iiArithAddCmd("prune",               0, 467, CMD_1, 151);
  iiArithAddCmd("qhweight",            0, 321, CMD_1, 152);
  iiArithAddCmd("qring",               0, 468, ROOT_DECL, 153);
  iiArithAddCmd("quote",               0, 370, 370, 154);
  iiArithAddCmd("quotient",            0, 320, CMD_2, 155);
  iiArithAddCmd("random",              0, 469, CMD_23, 156);
  iiArithAddCmd("read",                0, 470, CMD_12, 157);
  iiArithAddCmd("reduce",              0, 322, CMD_M, 158);
  iiArithAddCmd("regularity",          0, 323, CMD_1, 159);
  iiArithAddCmd("repart",              0, 471, CMD_1, 160);
  iiArithAddCmd("reservedName",        0, 472, CMD_M, 161);
  iiArithAddCmd("resolution",          0, 277, RING_DECL, 162);
  iiArithAddCmd("resultant",           0, 473, CMD_3, 163);
  iiArithAddCmd("return",              0, 375, 375, 164);
  iiArithAddCmd("ring",                0, 269, 269, 165);
  iiArithAddCmd("ringlist",            0, 474, CMD_1, 166);
#ifdef HAVE_RTIMER
  iiArithAddCmd("rtimer",              0, 496, SYSVAR, 167);
#endif
  iiArithAddCmd("rvar",                0, 438, CMD_1, 168);
  iiArithAddCmd("setring",             0, 358, 358, 169);
  iiArithAddCmd("short",               0, 499, SYSVAR, 170);
  iiArithAddCmd("simplex",             0, 476, CMD_M, 171);
  iiArithAddCmd("simplify",            0, 325, CMD_2, 172);
  iiArithAddCmd("size",                0, 406, CMD_1, 173);
  iiArithAddCmd("slimgb",              0, 477, CMD_1, 174);
  iiArithAddCmd("sortvec",             0, 326, CMD_1, 175);
  iiArithAddCmd("sres",                0, 327, CMD_2, 176);
  iiArithAddCmd("status",              0, 479, CMD_M, 177);
  iiArithAddCmd("std",                 0, 328, CMD_123, 178);
  iiArithAddCmd("string",              0, 480, ROOT_DECL_LIST, 179);
  iiArithAddCmd("subst",               0, 329, CMD_M, 180);
  iiArithAddCmd("system",              0, 481, CMD_M, 181);
  iiArithAddCmd("syz",                 0, 330, CMD_1, 182);
  iiArithAddCmd("test",                0, 482, CMD_M, 183);
  iiArithAddCmd("timer",               0, 495, SYSVAR, 184);
  iiArithAddCmd("trace",               0, 484, CMD_1, 185);
  iiArithAddCmd("transpose",           0, 483, CMD_1, 186);
  iiArithAddCmd("twostd",              0, 485, CMD_1, 187);
  iiArithAddCmd("type",                0, 359, 359, 188);
  iiArithAddCmd("typeof",              0, 486, CMD_1, 189);
  iiArithAddCmd("uressolve",           0, 488, CMD_M, 190);
  iiArithAddCmd("vandermonde",         0, 489, CMD_3, 191);
  iiArithAddCmd("var",                 0, 331, CMD_1, 192);
  iiArithAddCmd("varstr",              0, 490, CMD_12, 193);
  iiArithAddCmd("vdim",                0, 332, CMD_1, 194);
  iiArithAddCmd("vector",              0, 278, RING_DECL, 195);
  iiArithAddCmd("verbose",             2, 460, CMD_M, 196);
  iiArithAddCmd("voice",               0, 498, SYSVAR, 197);
  iiArithAddCmd("wedge",               0, 333, CMD_2, 198);
  iiArithAddCmd("weight",              0, 334, CMD_1, 199);
  iiArithAddCmd("whileif",             0, 372, 372, 200);
  iiArithAddCmd("write",               0, 491, CMD_M, 201);
  iiArithAddCmd("exit",                0,  -1, 0, 202);
  iiArithAddCmd("for",                 0,  -1, 0, 203);
  iiArithAddCmd("help",                0,  -1, 0, 204);
  iiArithAddCmd("newline",             0,  -1, 0, 205);
  iiArithAddCmd("pause",               2,  -1, 0, 206);
  iiArithAddCmd("quit",                0,  -1, 0, 207);
  iiArithAddCmd("while",               0,  -1, 0, 208);
/* end of list marker */
#ifdef HAVE_RTIMER
  sArithBase.nLastIdentifier = 201;
#else /* HAVE_RTIMER */
  sArithBase.nLastIdentifier = 200;
#endif /* HAVE_RTIMER */
}
#ifdef HAVE_RTIMER
#define LAST_IDENTIFIER 201
#else
#define LAST_IDENTIFIER 200
#endif
